using Diligent.WebAPI.Business.Interfaces;
using Diligent.WebAPI.Data;
using Diligent.WebAPI.Data.Entities;
using MongoDB.Driver;

namespace Diligent.WebAPI.Business.Services
{
    public class RoomRepository : BaseRepository<Room>, IRoomRepository
    {
        protected new IMongoCollection<Request> _dbCollection;

        public RoomRepository(IMongoDBContext context) : base(context)
        {
            _dbCollection = _mongoContext.GetCollection<Request>(typeof(Request).Name);
        }

        public Task<bool> AddCustomerToRoom(string customerId, string roomId)
        {
            throw new NotImplementedException();
        }

        public Task<bool> AddMessage(string roomId, Message message)
        {
            throw new NotImplementedException();
        }

        public Task<List<Message>> GetMessagesForSpecificRoom(string roomId)
        {
            throw new NotImplementedException();
        }

        public Task<List<Room>> GetRoomsWhichSupportCreated(string supportId)
        {
            throw new NotImplementedException();
        }

        public Task<List<Room>?> GetRoomsWithFilteredMessages(string customerId)
        {
            throw new NotImplementedException();
        }

        public Task<bool> LeaveChatRoom(string roomId, string userId)
        {
            throw new NotImplementedException();
        }
    }
}
