using Diligent.WebAPI.Data.Entities;

namespace Diligent.WebAPI.Business.Interfaces
{
    public interface IRoomRepository : IBaseRepository<Room>
    {
        Task<bool> AddCustomerToRoom(string customerId, string roomId);
        Task<bool> AddMessage(string roomId, Message message);
        Task<List<Message>> GetMessagesForSpecificRoom(string roomId);
        Task<bool> LeaveChatRoom(string roomId, string userId);
        Task<List<Room>> GetRoomsWhichSupportCreated(string supportId);
        Task<List<Room>?> GetRoomsWithFilteredMessages(string customerId);
    }
}
